@@ -4,10 +4,14 @@ from optparse import OptionParser
 import re
 import sys
 
-from argparse import ArgumentParser, RawDescriptionHelpFormatter
+try:
+    import argparse
+    from argparse import ArgumentParser, RawDescriptionHelpFormatter
+except ImportError:
+    argparse = None
 
 
-__version__ = '0.2.2'
+__version__ = '0.3'
 __author__ = 'Hideo Hattroi <hhatto.jp@gmail.com>'
 __license__ = 'NewBSDLicense'
 
@@ -33,15 +37,15 @@ def get_parser_type(parser_obj):
 def _escape_strings(strings):
     """escape to squarebracket and doublequote.
 
-    >>> print _escape_strings("hoge")
+    >>> print(_escape_strings("hoge"))
     hoge
-    >>> print _escape_strings("[hoge")
+    >>> print(_escape_strings("[hoge"))
     \[hoge
-    >>> print _escape_strings("hoge]")
+    >>> print(_escape_strings("hoge]"))
     hoge\]
-    >>> print _escape_strings("[hoge]")
+    >>> print(_escape_strings("[hoge]"))
     \[hoge\]
-    >>> print _escape_strings('[ho"ge]')
+    >>> print(_escape_strings('[ho"ge]'))
     \[ho\"ge\]
     """
     ret = []
@@ -56,12 +60,14 @@ class ZshCompletionGenerator(object):
 
     """Generator of Zsh Completion Function"""
 
-    def __init__(self, commandname=None, parser=None, parser_type=None):
+    def __init__(self, commandname=None, parser=None, parser_type=None,
+                 output_format=None):
         self.commandname = commandname
         self.parser = parser
         if not parser_type:
             parser_type = get_parser_type(parser)
         self.parser_type = parser_type
+        self.output_format = output_format if output_format else 'zsh'
 
     def _get_dircomp(self, opt):
         """judged to directories and files completion.
@@ -90,8 +96,29 @@ class ZshCompletionGenerator(object):
                     return ""
         return ""
 
-    def get(self):
-        """return to string of zsh completion function."""
+    def _get_list_format(self):
+        """return to string of list format."""
+        if self.parser_type == 'optparse':
+            actions = self.parser.option_list
+        elif self.parser_type == 'argparse':
+            actions = self.parser._actions
+        ret = []
+        for action in actions:
+            if self.parser_type == 'optparse':
+                opts = [i for i in action._long_opts]
+                opts += [i for i in action._short_opts]
+            elif self.parser_type == 'argparse':
+                opts = action.option_strings
+            for opt in opts:
+                if action.help:
+                    tmp = "%s:%s" % (opt, _escape_strings(action.help))
+                else:
+                    tmp = "%s" % (opt)
+                ret.append(tmp)
+        return "\n".join(ret)
+
+    def _get_zsh_format(self):
+        """return to string of zsh completion function format."""
         if self.parser_type == 'optparse':
             actions = self.parser.option_list
         elif self.parser_type == 'argparse':
@@ -125,10 +152,15 @@ class ZshCompletionGenerator(object):
         ret.append("  \"*::args:_files\"")
         return "\n".join(ret)
 
+    def get(self):
+        """_get_XXX_format wrapper method"""
+        func = getattr(self, "_get_%s_format" % self.output_format)
+        return func()
+
 
 class HelpParser(object):
 
-    """converte from help-strins to optparse.OptionParser"""
+    """convert from help-strings to optparse.OptionParser"""
 
     def __init__(self, helpstrings):
         self.helplines = helpstrings.splitlines()
@@ -173,24 +205,28 @@ class HelpParser(object):
         :rtype: parser object class
         """
         if '--version' in self.parselines[0]:
-            if 'optparse' == self.parser_type:
-                parser = OptionParser(version="dummy")
-            else:
+            if argparse and 'argparse' == self.parser_type:
                 parser = ArgumentParser(
                             version='dummy',
                             formatter_class=RawDescriptionHelpFormatter)
-        else:
-            if 'optparse' == self.parser_type:
-                parser = OptionParser()
             else:
+                parser = OptionParser(version="dummy")
+        else:
+            if argparse and 'argparse' == self.parser_type:
                 parser = ArgumentParser(
                             formatter_class=RawDescriptionHelpFormatter)
+            else:
+                parser = OptionParser()
         for opt in option_list:
             if opt['short'] and self.parser_type is 'optparse':
+                if parser.has_option(opt['short']):
+                    parser.remove_option(opt['short'])
                 parser.add_option(opt['short'], opt['long'],
                                   metavar=opt['metavar'],
                                   help=opt['help'].strip())
             elif not opt['short'] and self.parser_type is 'optparse':
+                if parser.has_option(opt['short']):
+                    parser.remove_option(opt['short'])
                 parser.add_option(opt['long'],
                                   metavar=opt['metavar'],
                                   help=opt['help'].strip())
@@ -288,6 +324,8 @@ def main():
                            usage="usage: genzshcomp FILE\n"\
                                  "             or\n"\
                                  "       USER_SCRIPT --help | genzshcomp")
+    oparser.add_option("-f", "--output-format", dest="output_format",
+            help="output format type [zsh|list] (default: zsh)")
     (opts, args) = oparser.parse_args()
     if sys.stdin.isatty() and len(args):
         helptext = open(args[0]).read()
@@ -308,8 +346,9 @@ def main():
     help_parser = HelpParser(helptext)
     command_name = help_parser.get_commandname()
     option_parser = help_parser.help2optparse()
-    zshop = ZshCompletionGenerator(command_name, option_parser)
-    print zshop.get()
+    zshop = ZshCompletionGenerator(command_name, option_parser,
+                output_format=opts.output_format)
+    print(zshop.get())
     return 0
 
 
