@@ -1,16 +1,27 @@
 from unittest import TestCase, main
-from argparse import ArgumentParser
+try:
+    import argparse
+except ImportError:
+    argparse = None
 from optparse import OptionParser
 import sys
 import os
-sys.path.insert(0, os.path.abspath('./'))
+sys.path.insert(0,
+        os.path.split(os.path.abspath(os.path.dirname(__file__)))[0])
 import genzshcomp
 
 
+def available_argparse(func):
+    if not argparse:
+        func = None
+    return func
+
+
 class TestParserType(TestCase):
 
+    @available_argparse
     def test_argparse(self):
-        target = ArgumentParser()
+        target = argparse.ArgumentParser()
         ret = genzshcomp.get_parser_type(target)
         self.assertEqual(ret, "argparse")
 
@@ -63,28 +74,33 @@ class TestEscape(TestCase):
 
 class TestReturnDirCompString(TestCase):
 
+    @available_argparse
     def test_argparse_help_short(self):
-        parser = ArgumentParser()
+        parser = argparse.ArgumentParser()
         generator = genzshcomp.ZshCompletionGenerator('dummy', parser)
         self.assertEqual(':', generator._get_dircomp('-h'))
 
+    @available_argparse
     def test_argparse_help_long(self):
-        parser = ArgumentParser()
+        parser = argparse.ArgumentParser()
         generator = genzshcomp.ZshCompletionGenerator('dummy', parser)
         self.assertEqual(':', generator._get_dircomp('--help'))
 
+    @available_argparse
     def test_argparse_version_short(self):
-        parser = ArgumentParser()
+        parser = argparse.ArgumentParser()
         generator = genzshcomp.ZshCompletionGenerator('dummy', parser)
         self.assertEqual(':', generator._get_dircomp('-v'))
 
+    @available_argparse
     def test_argparse_version_long(self):
-        parser = ArgumentParser()
+        parser = argparse.ArgumentParser()
         generator = genzshcomp.ZshCompletionGenerator('dummy', parser)
         self.assertEqual(':', generator._get_dircomp('--version'))
 
+    @available_argparse
     def test_argparse_dirfiles(self):
-        parser = ArgumentParser()
+        parser = argparse.ArgumentParser()
         generator = genzshcomp.ZshCompletionGenerator('dummy', parser)
         self.assertEqual('', generator._get_dircomp('-c'))
 
@@ -158,38 +174,42 @@ class TestHelpParser(TestCase):
         self.assertEqual(parser.has_option('-t'), False)
         self.assertEqual(parser.has_option('--text'), True)
 
+    @available_argparse
     def test_parser_type_is_argparse(self):
         hp = genzshcomp.HelpParser("optional arguments:")
         optlist = [{'short': None, 'long': '--text',
                     'metavar': None, 'help': "help string"}]
         self.assertEqual(type(hp._get_parserobj(optlist)),
-                         type(ArgumentParser()))
+                         type(argparse.ArgumentParser()))
 
+    @available_argparse
     def test_argparse_short_and_long(self):
         hp = genzshcomp.HelpParser("optional arguments:")
         optlist = [{'short': '-t', 'long': '--text',
                     'metavar': None, 'help': "help string"}]
         parser = hp._get_parserobj(optlist)
-        self.assertEqual(type(parser), type(ArgumentParser()))
+        self.assertEqual(type(parser), type(argparse.ArgumentParser()))
         self.assertNotEqual(len(parser._get_option_tuples('-t')), 0)
         self.assertNotEqual(len(parser._get_option_tuples('--text')), 0)
 
+    #@available_argparse
     #def test_argparse_short(self):
     #    """test invalid"""
     #    hp = genzshcomp.HelpParser("optional arguments:")
     #    optlist = [{'short': '-t', 'long': None,
     #                'metavar': None, 'help': "help string"}]
     #    parser = hp._get_parserobj(optlist)
-    #    self.assertEqual(type(parser), type(ArgumentParser()))
+    #    self.assertEqual(type(parser), type(argparse.ArgumentParser()))
     #    self.assertNotEqual(len(parser._get_option_tuples('-t')), 0)
     #    self.assertEqual(len(parser._get_option_tuples('--text')), 0)
 
+    @available_argparse
     def test_argparse_long(self):
         hp = genzshcomp.HelpParser("optional arguments:")
         optlist = [{'short': None, 'long': '--text',
                     'metavar': None, 'help': "help string"}]
         parser = hp._get_parserobj(optlist)
-        self.assertEqual(type(parser), type(ArgumentParser()))
+        self.assertEqual(type(parser), type(argparse.ArgumentParser()))
         self.assertNotEqual(len(parser._get_option_tuples('--text')), 0)
 
     def test_double_dash_in_helpstring(self):
@@ -388,5 +408,47 @@ Options:
         self.assertEqual(True, oparser.has_option("-L"))
         self.assertEqual(True, oparser.has_option("--http-proxy"))
 
+    def test_own(self):
+        help_string = """\
+Usage: genzshcomp FILE
+             or
+       USER_SCRIPT --help | genzshcomp
+
+automatic generated to zsh completion function file
+
+Options:
+  --version   show program's version number and exit
+  -h, --help  show this help message and exit
+        """
+        hp = genzshcomp.HelpParser(help_string)
+        oparser = hp.help2optparse()
+        self.assertEqual(True, oparser.has_option("-h"))
+        self.assertEqual(True, oparser.has_option("--help"))
+        self.assertEqual(True, oparser.has_option("--version"))
+
+
+class TestGenList(TestCase):
+
+    def test_own(self):
+        help_string = """\
+Usage: genzshcomp FILE
+             or
+       USER_SCRIPT --help | genzshcomp
+
+automatic generated to zsh completion function file
+
+Options:
+  --version   show program's version number and exit
+  -h, --help  show this help message and exit
+        """
+        hp = genzshcomp.HelpParser(help_string)
+        oparser = hp.help2optparse()
+        parser = OptionParser()
+        zshop = genzshcomp.ZshCompletionGenerator('dummy', parser,
+                    output_format='list')
+        zshlist = zshop.get()
+        self.assertEqual(True, '--help:show' in zshlist)
+
+
 if __name__ == '__main__':
     main()
